'use strict';

var extensions = require('./extensions.js');
var constants = require('./constants.js');
var adapter = require('./settings/adapter.js');
var settings = require('./settings/settings.js');
var Circle = require('./math/shapes/Circle.js');
var Ellipse = require('./math/shapes/Ellipse.js');
var Polygon = require('./math/shapes/Polygon.js');
var Rectangle = require('./math/shapes/Rectangle.js');
var RoundedRectangle = require('./math/shapes/RoundedRectangle.js');
var groupD8 = require('./math/groupD8.js');
var Matrix = require('./math/Matrix.js');
var ObservablePoint = require('./math/ObservablePoint.js');
var Point = require('./math/Point.js');
var Transform = require('./math/Transform.js');
var _const = require('./math/const.js');
var index = require('./core/index.js');
var index$1 = require('./utils/index.js');
var color = require('./color.js');
require('./ticker/settings.js');
var _const$1 = require('./ticker/const.js');
var Ticker = require('./ticker/Ticker.js');
var TickerPlugin = require('./ticker/TickerPlugin.js');
var runner = require('./runner.js');
require('./display/settings.js');
var Bounds = require('./display/Bounds.js');
var Container = require('./display/Container.js');
var DisplayObject = require('./display/DisplayObject.js');
var sprite = require('./sprite.js');
var Spritesheet = require('./spritesheet/Spritesheet.js');
var Mesh = require('./mesh/Mesh.js');
var MeshBatchUvs = require('./mesh/MeshBatchUvs.js');
var MeshGeometry = require('./mesh/MeshGeometry.js');
var MeshMaterial = require('./mesh/MeshMaterial.js');
var _const$3 = require('./text/const.js');
var Text = require('./text/Text.js');
var TextMetrics = require('./text/TextMetrics.js');
var TextStyle = require('./text/TextStyle.js');
var BitmapFont = require('./text-bitmap/BitmapFont.js');
var BitmapFontData = require('./text-bitmap/BitmapFontData.js');
var BitmapText = require('./text-bitmap/BitmapText.js');
var index$4 = require('./text-bitmap/formats/index.js');
var HTMLText = require('./text-html/HTMLText.js');
var HTMLTextStyle = require('./text-html/HTMLTextStyle.js');
var index$5 = require('./graphics/index.js');
var TFBufferCopier = require('./hacks/TFBufferCopier.js');
var LayerPass = require('./layers/LayerPass.js');
var LayerTextureCache = require('./layers/LayerTextureCache.js');
var PassSystem = require('./layers/PassSystem.js');
var autoDetectRenderer = require('./core/autoDetectRenderer.js');
var BackgroundSystem = require('./core/background/BackgroundSystem.js');
var BatchDrawCall = require('./core/batch/BatchDrawCall.js');
var BatchGeometry = require('./core/batch/BatchGeometry.js');
var BatchRenderer = require('./core/batch/BatchRenderer.js');
var BatchShaderGenerator = require('./core/batch/BatchShaderGenerator.js');
var BatchSystem = require('./core/batch/BatchSystem.js');
var BatchTextureArray = require('./core/batch/BatchTextureArray.js');
var ObjectRenderer = require('./core/batch/ObjectRenderer.js');
var ContextSystem = require('./core/context/ContextSystem.js');
var Filter = require('./core/filters/Filter.js');
var FilterState = require('./core/filters/FilterState.js');
var FilterSystem = require('./core/filters/FilterSystem.js');
var SpriteMaskFilter = require('./core/filters/spriteMask/SpriteMaskFilter.js');
var index$2 = require('./core/fragments/index.js');
var Framebuffer = require('./core/framebuffer/Framebuffer.js');
var FramebufferSystem = require('./core/framebuffer/FramebufferSystem.js');
var GLFramebuffer = require('./core/framebuffer/GLFramebuffer.js');
var MultisampleSystem = require('./core/framebuffer/MultisampleSystem.js');
var Attribute = require('./core/geometry/Attribute.js');
var Buffer = require('./core/geometry/Buffer.js');
var BufferSystem = require('./core/geometry/BufferSystem.js');
var Geometry = require('./core/geometry/Geometry.js');
var GeometrySystem = require('./core/geometry/GeometrySystem.js');
var ViewableBuffer = require('./core/geometry/ViewableBuffer.js');
var BufferCopyOperation = require('./core/geometry/BufferCopyOperation.js');
var MaskData = require('./core/mask/MaskData.js');
var MaskSystem = require('./core/mask/MaskSystem.js');
var ScissorSystem = require('./core/mask/ScissorSystem.js');
var StencilSystem = require('./core/mask/StencilSystem.js');
var PluginSystem = require('./core/plugin/PluginSystem.js');
var ProjectionSystem = require('./core/projection/ProjectionSystem.js');
var ObjectRendererSystem = require('./core/render/ObjectRendererSystem.js');
var Renderer = require('./core/Renderer.js');
var BaseRenderTexture = require('./core/renderTexture/BaseRenderTexture.js');
var GenerateTextureSystem = require('./core/renderTexture/GenerateTextureSystem.js');
var RenderTexture = require('./core/renderTexture/RenderTexture.js');
var RenderTexturePool = require('./core/renderTexture/RenderTexturePool.js');
var RenderTextureSystem = require('./core/renderTexture/RenderTextureSystem.js');
var GLProgram = require('./core/shader/GLProgram.js');
var Program = require('./core/shader/Program.js');
var Shader = require('./core/shader/Shader.js');
var ShaderSystem = require('./core/shader/ShaderSystem.js');
var UniformGroup = require('./core/shader/UniformGroup.js');
var checkMaxIfStatementsInShader = require('./core/shader/utils/checkMaxIfStatementsInShader.js');
var generateProgram = require('./core/shader/utils/generateProgram.js');
var generateUniformBufferSync = require('./core/shader/utils/generateUniformBufferSync.js');
var getTestContext = require('./core/shader/utils/getTestContext.js');
var uniformParsers = require('./core/shader/utils/uniformParsers.js');
var unsafeEvalSupported = require('./core/shader/utils/unsafeEvalSupported.js');
var StartupSystem = require('./core/startup/StartupSystem.js');
var State = require('./core/state/State.js');
var StateSystem = require('./core/state/StateSystem.js');
var SystemManager = require('./core/system/SystemManager.js');
var TextureGCSystem = require('./core/textures/TextureGCSystem.js');
var TextureSystem = require('./core/textures/TextureSystem.js');
var TransformFeedbackSystem = require('./core/transformFeedback/TransformFeedbackSystem.js');
var ViewSystem = require('./core/view/ViewSystem.js');
var BaseTexture = require('./core/textures/BaseTexture.js');
var GLTexture = require('./core/textures/GLTexture.js');
var BaseImageResource = require('./core/textures/resources/BaseImageResource.js');
var Resource = require('./core/textures/resources/Resource.js');
var AbstractMultiResource = require('./core/textures/resources/AbstractMultiResource.js');
var ArrayResource = require('./core/textures/resources/ArrayResource.js');
var autoDetectResource = require('./core/textures/resources/autoDetectResource.js');
var BufferResource = require('./core/textures/resources/BufferResource.js');
var Buffer3DResource = require('./core/textures/resources/Buffer3DResource.js');
var CanvasResource = require('./core/textures/resources/CanvasResource.js');
var CubeResource = require('./core/textures/resources/CubeResource.js');
var ImageBitmapResource = require('./core/textures/resources/ImageBitmapResource.js');
var ImageResource = require('./core/textures/resources/ImageResource.js');
var SVGResource = require('./core/textures/resources/SVGResource.js');
var VideoResource = require('./core/textures/resources/VideoResource.js');
var Texture = require('./core/textures/Texture.js');
var TextureMatrix = require('./core/textures/TextureMatrix.js');
var TextureUvs = require('./core/textures/TextureUvs.js');
var Texture3D = require('./core/textures/Texture3D.js');
var Texture3DLayout = require('./core/textures/Texture3DLayout.js');
var TransformFeedback = require('./core/transformFeedback/TransformFeedback.js');
var Quad = require('./core/utils/Quad.js');
var QuadUv = require('./core/utils/QuadUv.js');
var index$3 = require('./utils/is_mobile/index.js');
var event_emitter = require('./utils/event_emitter.js');
var earcut = require('./utils/earcut.js');
var path = require('./utils/path.js');
var detectVideoAlphaMode = require('./utils/browser/detectVideoAlphaMode.js');
var hello = require('./utils/browser/hello.js');
var isWebGLSupported = require('./utils/browser/isWebGLSupported.js');
var hex = require('./utils/color/hex.js');
var premultiply = require('./utils/color/premultiply.js');
var _const$2 = require('./utils/const.js');
var createIndicesForQuads = require('./utils/data/createIndicesForQuads.js');
var getBufferType = require('./utils/data/getBufferType.js');
var interleaveTypedArrays = require('./utils/data/interleaveTypedArrays.js');
var pow2 = require('./utils/data/pow2.js');
var removeItems = require('./utils/data/removeItems.js');
var sign = require('./utils/data/sign.js');
var uid = require('./utils/data/uid.js');
var deprecation = require('./utils/logging/deprecation.js');
var BoundingBox = require('./utils/media/BoundingBox.js');
var caches = require('./utils/media/caches.js');
var CanvasRenderTarget = require('./utils/media/CanvasRenderTarget.js');
var getCanvasBoundingBox = require('./utils/media/getCanvasBoundingBox.js');
var trimCanvas = require('./utils/media/trimCanvas.js');
var decomposeDataUri = require('./utils/network/decomposeDataUri.js');
var determineCrossOrigin = require('./utils/network/determineCrossOrigin.js');
var getResolutionOfUrl = require('./utils/network/getResolutionOfUrl.js');
var TextFormat = require('./text-bitmap/formats/TextFormat.js');
var XMLFormat = require('./text-bitmap/formats/XMLFormat.js');
var XMLStringFormat = require('./text-bitmap/formats/XMLStringFormat.js');
var _const$4 = require('./graphics/const.js');
var Graphics = require('./graphics/Graphics.js');
var GraphicsData = require('./graphics/GraphicsData.js');
var GraphicsGeometry = require('./graphics/GraphicsGeometry.js');
var FillStyle = require('./graphics/styles/FillStyle.js');
var LineStyle = require('./graphics/styles/LineStyle.js');



Object.defineProperty(exports, 'ExtensionType', {
	enumerable: true,
	get: function () { return extensions.ExtensionType; }
});
exports.extensions = extensions.extensions;
Object.defineProperty(exports, 'ALPHA_MODES', {
	enumerable: true,
	get: function () { return constants.ALPHA_MODES; }
});
Object.defineProperty(exports, 'BLEND_MODES', {
	enumerable: true,
	get: function () { return constants.BLEND_MODES; }
});
Object.defineProperty(exports, 'BUFFER_BITS', {
	enumerable: true,
	get: function () { return constants.BUFFER_BITS; }
});
Object.defineProperty(exports, 'BUFFER_TYPE', {
	enumerable: true,
	get: function () { return constants.BUFFER_TYPE; }
});
Object.defineProperty(exports, 'CLEAR_MODES', {
	enumerable: true,
	get: function () { return constants.CLEAR_MODES; }
});
Object.defineProperty(exports, 'COLOR_MASK_BITS', {
	enumerable: true,
	get: function () { return constants.COLOR_MASK_BITS; }
});
Object.defineProperty(exports, 'DRAW_MODES', {
	enumerable: true,
	get: function () { return constants.DRAW_MODES; }
});
Object.defineProperty(exports, 'ENV', {
	enumerable: true,
	get: function () { return constants.ENV; }
});
Object.defineProperty(exports, 'FORMATS', {
	enumerable: true,
	get: function () { return constants.FORMATS; }
});
Object.defineProperty(exports, 'GC_MODES', {
	enumerable: true,
	get: function () { return constants.GC_MODES; }
});
Object.defineProperty(exports, 'MASK_TYPES', {
	enumerable: true,
	get: function () { return constants.MASK_TYPES; }
});
Object.defineProperty(exports, 'MIPMAP_MODES', {
	enumerable: true,
	get: function () { return constants.MIPMAP_MODES; }
});
Object.defineProperty(exports, 'MSAA_QUALITY', {
	enumerable: true,
	get: function () { return constants.MSAA_QUALITY; }
});
Object.defineProperty(exports, 'PRECISION', {
	enumerable: true,
	get: function () { return constants.PRECISION; }
});
Object.defineProperty(exports, 'RENDERER_TYPE', {
	enumerable: true,
	get: function () { return constants.RENDERER_TYPE; }
});
Object.defineProperty(exports, 'SAMPLER_TYPES', {
	enumerable: true,
	get: function () { return constants.SAMPLER_TYPES; }
});
Object.defineProperty(exports, 'SCALE_MODES', {
	enumerable: true,
	get: function () { return constants.SCALE_MODES; }
});
Object.defineProperty(exports, 'TARGETS', {
	enumerable: true,
	get: function () { return constants.TARGETS; }
});
Object.defineProperty(exports, 'TYPES', {
	enumerable: true,
	get: function () { return constants.TYPES; }
});
Object.defineProperty(exports, 'WRAP_MODES', {
	enumerable: true,
	get: function () { return constants.WRAP_MODES; }
});
exports.BrowserAdapter = adapter.BrowserAdapter;
exports.settings = settings.settings;
exports.Circle = Circle.Circle;
exports.Ellipse = Ellipse.Ellipse;
exports.Polygon = Polygon.Polygon;
exports.Rectangle = Rectangle.Rectangle;
exports.RoundedRectangle = RoundedRectangle.RoundedRectangle;
exports.groupD8 = groupD8.groupD8;
exports.Matrix = Matrix.Matrix;
exports.ObservablePoint = ObservablePoint.ObservablePoint;
exports.Point = Point.Point;
exports.Transform = Transform.Transform;
exports.DEG_TO_RAD = _const.DEG_TO_RAD;
exports.PI_2 = _const.PI_2;
exports.RAD_TO_DEG = _const.RAD_TO_DEG;
Object.defineProperty(exports, 'SHAPES', {
	enumerable: true,
	get: function () { return _const.SHAPES; }
});
exports.VERSION = index.VERSION;
exports.utils = index$1;
exports.Color = color.Color;
Object.defineProperty(exports, 'UPDATE_PRIORITY', {
	enumerable: true,
	get: function () { return _const$1.UPDATE_PRIORITY; }
});
exports.Ticker = Ticker.Ticker;
exports.TickerPlugin = TickerPlugin.TickerPlugin;
exports.Runner = runner.Runner;
exports.Bounds = Bounds.Bounds;
exports.Container = Container.Container;
exports.DisplayObject = DisplayObject.DisplayObject;
exports.TemporaryDisplayObject = DisplayObject.TemporaryDisplayObject;
exports.Sprite = sprite.Sprite;
exports.Spritesheet = Spritesheet.Spritesheet;
exports.Mesh = Mesh.Mesh;
exports.MeshBatchUvs = MeshBatchUvs.MeshBatchUvs;
exports.MeshGeometry = MeshGeometry.MeshGeometry;
exports.MeshMaterial = MeshMaterial.MeshMaterial;
Object.defineProperty(exports, 'TEXT_GRADIENT', {
	enumerable: true,
	get: function () { return _const$3.TEXT_GRADIENT; }
});
exports.Text = Text.Text;
exports.TextMetrics = TextMetrics.TextMetrics;
exports.TextStyle = TextStyle.TextStyle;
exports.BitmapFont = BitmapFont.BitmapFont;
exports.BitmapFontData = BitmapFontData.BitmapFontData;
exports.BitmapText = BitmapText.BitmapText;
exports.autoDetectFormat = index$4.autoDetectFormat;
exports.HTMLText = HTMLText.HTMLText;
exports.HTMLTextStyle = HTMLTextStyle.HTMLTextStyle;
exports.graphicsUtils = index$5.graphicsUtils;
exports.TFBufferCopier = TFBufferCopier.TFBufferCopier;
exports.LayerPass = LayerPass.LayerPass;
exports.LayerTextureCache = LayerTextureCache.LayerTextureCache;
exports.PassSystem = PassSystem.PassSystem;
exports.autoDetectRenderer = autoDetectRenderer.autoDetectRenderer;
exports.BackgroundSystem = BackgroundSystem.BackgroundSystem;
exports.BatchDrawCall = BatchDrawCall.BatchDrawCall;
exports.BatchGeometry = BatchGeometry.BatchGeometry;
exports.BatchRenderer = BatchRenderer.BatchRenderer;
exports.BatchShaderGenerator = BatchShaderGenerator.BatchShaderGenerator;
exports.BatchSystem = BatchSystem.BatchSystem;
exports.BatchTextureArray = BatchTextureArray.BatchTextureArray;
exports.ObjectRenderer = ObjectRenderer.ObjectRenderer;
exports.ContextSystem = ContextSystem.ContextSystem;
exports.Filter = Filter.Filter;
exports.FilterState = FilterState.FilterState;
exports.FilterSystem = FilterSystem.FilterSystem;
exports.SpriteMaskFilter = SpriteMaskFilter.SpriteMaskFilter;
exports.defaultFilterVertex = index$2.defaultFilterVertex;
exports.defaultVertex = index$2.defaultVertex;
exports.Framebuffer = Framebuffer.Framebuffer;
exports.FramebufferSystem = FramebufferSystem.FramebufferSystem;
exports.GLFramebuffer = GLFramebuffer.GLFramebuffer;
exports.MultisampleSystem = MultisampleSystem.MultisampleSystem;
exports.Attribute = Attribute.Attribute;
exports.Buffer = Buffer.Buffer;
exports.BufferSystem = BufferSystem.BufferSystem;
exports.Geometry = Geometry.Geometry;
exports.GeometryPerGL = Geometry.GeometryPerGL;
exports.GeometryPerShader = Geometry.GeometryPerShader;
exports.GeometrySystem = GeometrySystem.GeometrySystem;
exports.ViewableBuffer = ViewableBuffer.ViewableBuffer;
exports.BufferCopyOperation = BufferCopyOperation.BufferCopyOperation;
exports.MaskData = MaskData.MaskData;
exports.MaskSystem = MaskSystem.MaskSystem;
exports.ScissorSystem = ScissorSystem.ScissorSystem;
exports.StencilSystem = StencilSystem.StencilSystem;
exports.PluginSystem = PluginSystem.PluginSystem;
exports.ProjectionSystem = ProjectionSystem.ProjectionSystem;
exports.ObjectRendererSystem = ObjectRendererSystem.ObjectRendererSystem;
exports.Renderer = Renderer.Renderer;
exports.BaseRenderTexture = BaseRenderTexture.BaseRenderTexture;
exports.GenerateTextureSystem = GenerateTextureSystem.GenerateTextureSystem;
exports.RenderTexture = RenderTexture.RenderTexture;
exports.RenderTexturePool = RenderTexturePool.RenderTexturePool;
exports.RenderTextureSystem = RenderTextureSystem.RenderTextureSystem;
exports.GLProgram = GLProgram.GLProgram;
exports.IGLUniformData = GLProgram.IGLUniformData;
exports.Program = Program.Program;
exports.Shader = Shader.Shader;
exports.ShaderSystem = ShaderSystem.ShaderSystem;
exports.UniformGroup = UniformGroup.UniformGroup;
exports.checkMaxIfStatementsInShader = checkMaxIfStatementsInShader.checkMaxIfStatementsInShader;
exports.generateProgram = generateProgram.generateProgram;
exports.createUBOElements = generateUniformBufferSync.createUBOElements;
exports.generateUniformBufferSync = generateUniformBufferSync.generateUniformBufferSync;
exports.getUBOData = generateUniformBufferSync.getUBOData;
exports.getTestContext = getTestContext.getTestContext;
exports.uniformParsers = uniformParsers.uniformParsers;
exports.unsafeEvalSupported = unsafeEvalSupported.unsafeEvalSupported;
exports.StartupSystem = StartupSystem.StartupSystem;
exports.State = State.State;
exports.StateSystem = StateSystem.StateSystem;
exports.SystemManager = SystemManager.SystemManager;
exports.TextureGCSystem = TextureGCSystem.TextureGCSystem;
exports.TextureSystem = TextureSystem.TextureSystem;
exports.TransformFeedbackSystem = TransformFeedbackSystem.TransformFeedbackSystem;
exports.ViewSystem = ViewSystem.ViewSystem;
exports.BaseTexture = BaseTexture.BaseTexture;
exports.GLTexture = GLTexture.GLTexture;
exports.BaseImageResource = BaseImageResource.BaseImageResource;
exports.Resource = Resource.Resource;
exports.AbstractMultiResource = AbstractMultiResource.AbstractMultiResource;
exports.ArrayResource = ArrayResource.ArrayResource;
exports.INSTALLED = autoDetectResource.INSTALLED;
exports.autoDetectResource = autoDetectResource.autoDetectResource;
exports.BufferResource = BufferResource.BufferResource;
exports.Buffer3DResource = Buffer3DResource.Buffer3DResource;
exports.formatToCount = Buffer3DResource.formatToCount;
exports.CanvasResource = CanvasResource.CanvasResource;
exports.CubeResource = CubeResource.CubeResource;
exports.ImageBitmapResource = ImageBitmapResource.ImageBitmapResource;
exports.ImageResource = ImageResource.ImageResource;
exports.SVGResource = SVGResource.SVGResource;
exports.VideoResource = VideoResource.VideoResource;
exports.Texture = Texture.Texture;
exports.TextureMatrix = TextureMatrix.TextureMatrix;
exports.TextureUvs = TextureUvs.TextureUvs;
exports.Texture3D = Texture3D.Texture3D;
exports.Texture3DLayout = Texture3DLayout.Texture3DLayout;
exports.TransformFeedback = TransformFeedback.TransformFeedback;
exports.Quad = Quad.Quad;
exports.QuadUv = QuadUv.QuadUv;
exports.isMobile = index$3.isMobile;
exports.EventEmitter = event_emitter.EventEmitter;
exports.earcut = earcut.earcut;
exports.path = path.path;
exports.detectVideoAlphaMode = detectVideoAlphaMode.detectVideoAlphaMode;
exports.sayHello = hello.sayHello;
exports.skipHello = hello.skipHello;
exports.isWebGLSupported = isWebGLSupported.isWebGLSupported;
exports.hex2rgb = hex.hex2rgb;
exports.hex2string = hex.hex2string;
exports.rgb2hex = hex.rgb2hex;
exports.string2hex = hex.string2hex;
exports.correctBlendMode = premultiply.correctBlendMode;
exports.premultiplyBlendMode = premultiply.premultiplyBlendMode;
exports.premultiplyRgba = premultiply.premultiplyRgba;
exports.premultiplyTint = premultiply.premultiplyTint;
exports.premultiplyTintToRgba = premultiply.premultiplyTintToRgba;
exports.DATA_URI = _const$2.DATA_URI;
exports.createIndicesForQuads = createIndicesForQuads.createIndicesForQuads;
exports.getBufferType = getBufferType.getBufferType;
exports.interleaveTypedArrays = interleaveTypedArrays.interleaveTypedArrays;
exports.isPow2 = pow2.isPow2;
exports.log2 = pow2.log2;
exports.nextPow2 = pow2.nextPow2;
exports.removeItems = removeItems.removeItems;
exports.sign = sign.sign;
exports.uid = uid.uid;
exports.deprecation = deprecation.deprecation;
exports.BoundingBox = BoundingBox.BoundingBox;
exports.BaseTextureCache = caches.BaseTextureCache;
exports.ProgramCache = caches.ProgramCache;
exports.TextureCache = caches.TextureCache;
exports.clearTextureCache = caches.clearTextureCache;
exports.destroyTextureCache = caches.destroyTextureCache;
exports.CanvasRenderTarget = CanvasRenderTarget.CanvasRenderTarget;
exports.getCanvasBoundingBox = getCanvasBoundingBox.getCanvasBoundingBox;
exports.trimCanvas = trimCanvas.trimCanvas;
exports.decomposeDataUri = decomposeDataUri.decomposeDataUri;
exports.determineCrossOrigin = determineCrossOrigin.determineCrossOrigin;
exports.getResolutionOfUrl = getResolutionOfUrl.getResolutionOfUrl;
exports.TextFormat = TextFormat.TextFormat;
exports.XMLFormat = XMLFormat.XMLFormat;
exports.XMLStringFormat = XMLStringFormat.XMLStringFormat;
exports.GRAPHICS_CURVES = _const$4.GRAPHICS_CURVES;
Object.defineProperty(exports, 'LINE_CAP', {
	enumerable: true,
	get: function () { return _const$4.LINE_CAP; }
});
Object.defineProperty(exports, 'LINE_JOIN', {
	enumerable: true,
	get: function () { return _const$4.LINE_JOIN; }
});
exports.curves = _const$4.curves;
exports.Graphics = Graphics.Graphics;
exports.GraphicsData = GraphicsData.GraphicsData;
exports.GraphicsGeometry = GraphicsGeometry.GraphicsGeometry;
exports.FillStyle = FillStyle.FillStyle;
exports.LineStyle = LineStyle.LineStyle;
//# sourceMappingURL=index.js.map
